declare const config: {
    root: boolean;
    env: {
        node: boolean;
        browser: boolean;
        commonjs: boolean;
        es6: boolean;
    };
    parserOptions: {
        ecmaVersion: string;
        sourceType: string;
        ecmaFeatures: {
            experimentalObjectRestSpread: boolean;
            experimentalDecorators: boolean;
            jsx: boolean;
        };
    };
    ignorePatterns: string[];
    plugins: string[];
    extends: string[];
    settings: {
        'import/resolver': {
            node: {
                extensions: string[];
            };
        };
    };
    rules: {
        'no-console': (string | {
            allow: string[];
        })[];
        'no-debugger': number;
        semi: (string | number)[];
        quotes: string[];
        'comma-dangle': string;
        camelcase: (string | {
            properties: string;
        })[];
        'no-var': string;
        'no-empty': (string | {
            allowEmptyCatch: boolean;
        })[];
        'no-void': string;
        'one-var': (string | {
            var: string;
            let: string;
            const: string;
        })[];
        'no-throw-literal': string;
        'no-new-wrappers': number;
        'no-useless-escape': string;
        'no-redeclare': number;
        'no-tabs': string;
        indent: string;
        'no-mixed-spaces-and-tabs': string[];
        'space-before-function-paren': (string | number)[];
        'object-shorthand': number;
        'no-unused-vars': (number | {
            args: string;
            caughtErrors: string;
            ignoreRestSiblings: boolean;
            vars: string;
            argsIgnorePattern: string;
            varsIgnorePattern: string;
        })[];
        'no-dupe-keys': number;
        'no-func-assign': number;
        'valid-typeof': number;
        'no-shadow': string;
        'no-prototype-builtins': string;
        'no-undef': number;
        'no-irregular-whitespace': number;
        'array-callback-return': string;
        'block-scoped-var': string;
        'consistent-return': string;
        complexity: (string | number)[];
        eqeqeq: string[];
        'no-alert': string;
        'no-case-declarations': string;
        'no-multi-spaces': string;
        'no-multi-str': string;
        'no-with': string;
        'vars-on-top': string;
        'require-await': string;
        'no-return-assign': string;
        'operator-linebreak': string;
        'no-use-before-define': (string | {
            functions: boolean;
            classes: boolean;
            variables: boolean;
        })[];
        'no-template-curly-in-string': string;
        'no-extra-semi': string;
        'no-labels': number;
        'eslint-comments/disable-enable-pair': string;
        'import/order': string;
        'import/first': string;
        'import/no-duplicates': string;
        'import/no-mutable-exports': string;
        'import/no-unresolved': string;
        'import/no-absolute-path': string;
        'import/no-named-as-default': string;
        'import/no-named-as-default-member': string;
        'n/no-callback-literal': string;
        'prettier/prettier': string;
        'sort-imports': (string | {
            ignoreCase: boolean;
            ignoreDeclarationSort: boolean;
            ignoreMemberSort: boolean;
            memberSyntaxSortOrder: string[];
            allowSeparatedGroups: boolean;
        })[];
        'yml/quotes': (string | {
            prefer: string;
            avoidEscape: boolean;
        })[];
        'yml/no-empty-document': string;
        'unicorn/error-message': string;
        'unicorn/escape-case': string;
        'unicorn/no-array-instanceof': string;
        'unicorn/no-new-buffer': string;
        'unicorn/no-unsafe-regex': string;
        'unicorn/number-literal-case': string;
        'unicorn/prefer-exponentiation-operator': string;
        'unicorn/prefer-includes': string;
        'unicorn/prefer-starts-ends-with': string;
        'unicorn/prefer-text-content': string;
        'unicorn/prefer-type-error': string;
        'unicorn/throw-new-error': string;
    };
    globals: {
        document: string;
        navigator: string;
        window: string;
    };
    overrides: ({
        files: string[];
        parser: string;
        rules: {
            'jsonc/array-bracket-spacing': string[];
            'jsonc/comma-dangle': string[];
            'jsonc/comma-style': string[];
            'jsonc/indent': number;
            'jsonc/key-spacing': (string | {
                beforeColon: boolean;
                afterColon: boolean;
            })[];
            'jsonc/no-octal-escape': string;
            'jsonc/object-curly-newline': (string | {
                multiline: boolean;
                consistent: boolean;
            })[];
            'jsonc/object-curly-spacing': string[];
            'jsonc/object-property-newline': (string | {
                allowMultiplePropertiesPerLine: boolean;
            })[];
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-void'?: undefined;
            'no-console'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
    } | {
        files: string[];
        parser: string;
        rules: {
            'spaced-comment': string;
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-void'?: undefined;
            'no-console'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
    } | {
        files: string[];
        parser: string;
        rules: {
            'jsonc/sort-keys': (string | {
                pathPattern: string;
                order: string[];
            } | {
                pathPattern: string;
                order: {
                    type: string;
                };
            })[];
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'import/no-duplicates'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-void'?: undefined;
            'no-console'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
    } | {
        files: string[];
        rules: {
            'import/no-duplicates': string;
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-void'?: undefined;
            'no-console'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
        parser?: undefined;
    } | {
        files: string[];
        rules: {
            '@typescript-eslint/no-var-requires': string;
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            'no-void'?: undefined;
            'no-console'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
        parser?: undefined;
    } | {
        files: string[];
        rules: {
            'no-void': (string | {
                allowAsStatement: boolean;
            })[];
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-console'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
        parser?: undefined;
    } | {
        files: string[];
        rules: {
            'no-console': string;
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-void'?: undefined;
            'no-unused-expressions'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
        parser?: undefined;
    } | {
        files: string[];
        rules: {
            'no-unused-expressions': string;
            'no-only-tests/no-only-tests': string;
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            '@typescript-eslint/no-var-requires'?: undefined;
            'no-void'?: undefined;
            'no-console'?: undefined;
            '@typescript-eslint/no-redeclare'?: undefined;
            '@typescript-eslint/no-unused-vars'?: undefined;
            '@typescript-eslint/no-use-before-define'?: undefined;
            '@typescript-eslint/comma-dangle'?: undefined;
            '@typescript-eslint/consistent-type-imports'?: undefined;
            'import/no-unresolved'?: undefined;
            'no-alert'?: undefined;
            'no-restricted-imports'?: undefined;
            'no-undef'?: undefined;
            'no-unused-vars'?: undefined;
        };
        parser?: undefined;
    } | {
        files: string[];
        rules: {
            '@typescript-eslint/no-redeclare': string;
            '@typescript-eslint/no-unused-vars': string;
            '@typescript-eslint/no-use-before-define': string;
            '@typescript-eslint/no-var-requires': string;
            '@typescript-eslint/comma-dangle': string;
            '@typescript-eslint/consistent-type-imports': string;
            'import/no-unresolved': string;
            'no-alert': string;
            'no-console': string;
            'no-restricted-imports': string;
            'no-undef': string;
            'no-unused-expressions': string;
            'no-unused-vars': string;
            'jsonc/array-bracket-spacing'?: undefined;
            'jsonc/comma-dangle'?: undefined;
            'jsonc/comma-style'?: undefined;
            'jsonc/indent'?: undefined;
            'jsonc/key-spacing'?: undefined;
            'jsonc/no-octal-escape'?: undefined;
            'jsonc/object-curly-newline'?: undefined;
            'jsonc/object-curly-spacing'?: undefined;
            'jsonc/object-property-newline'?: undefined;
            'spaced-comment'?: undefined;
            'jsonc/sort-keys'?: undefined;
            'import/no-duplicates'?: undefined;
            'no-void'?: undefined;
            'no-only-tests/no-only-tests'?: undefined;
        };
        parser?: undefined;
    })[];
};
export default config;
